.. _changelog#1.1.1:

Translate Toolkit 1.1.1
=======================

*Released on 2 April 2008*

.. _changelog#premature_termination_of_dtd_entities:

Premature termination of DTD entities
-------------------------------------

Although this does not occur frequently a case emerged where some DTD entities
where not fully extracted from the DTD source.  This was fixed in :issue:`331`.

We expect this change to create a few new fuzzy entries.  There is no action
required from the user as the next update of your PO files will bring the
correct text into your translations, if you are using a translation memory your
translation might be recovered from obsolete translations.
